@@ -1603,8 +1603,12 @@ impl Fit {
 
             let mut error = false;
 
+            // Bytes to read is specified in the header as being the number of bytes after the header.
+            // We also need to subtract the two bytes for the CRC.
+            let bytes_to_read = self.header.header_len as u64 + self.header.data_size() as u64 - 2;
+
             // Read each record.
-            while !(reader.buffer().is_empty() || error) {
+            while !error && state.bytes_read < bytes_to_read {
 
                 let mut record = FitRecord::new();
                 let result = record.read(reader, &mut state, callback, context);
@@ -1612,8 +1616,8 @@ impl Fit {
                 match result {
                     Ok(_result) => {
                     }
-                    Err(_e) => {
-                        //println!("Error: {} Bytes Read: {}", e, state.bytes_read);
+                    Err(e) => {
+                        println!("Error: {} Bytes Read: {}", e, state.bytes_read);
                         error = true;
                     }
                 }
